@@ -1,7 +1,9 @@
 from .quart_extension import QuartMayimExtension
 from .sanic_extension import SanicMayimExtension
+from .starlette_extension import StarletteMayimExtension
 
 __all__ = (
     "QuartMayimExtension",
     "SanicMayimExtension",
+    "StarletteMayimExtension",
 )
