@@ -5,9 +5,8 @@ from inspect import isclass
 from typing import TYPE_CHECKING, DefaultDict, Dict, Optional, Set, Type, Union
 
 if TYPE_CHECKING:
-    from mayim.executor import Executor
-    from mayim.hydrator import Hydrator
-    from mayim.interface.base import BaseInterface
+    from mayim.base import Executor, Hydrator
+    from mayim.base.interface import BaseInterface
 
 
 class Registry(dict):
@@ -34,8 +33,7 @@ class InterfaceRegistry:
 
     def __new__(cls, *args, **kwargs):
         if cls._singleton is None:
-            cls._singleton = super().__new__(cls)
-            cls._singleton._interfaces = set()
+            cls.reset()
         return cls._singleton
 
     @classmethod
@@ -46,15 +44,19 @@ class InterfaceRegistry:
     def __iter__(self):
         return iter(self._interfaces)
 
+    @classmethod
+    def reset(cls):
+        cls._singleton = super().__new__(cls)
+        cls._singleton._interfaces = set()
 
-class LazySQLRegistry:
+
+class LazyQueryRegistry:
     _singleton = None
     _queries: DefaultDict[str, Dict[str, str]]
 
     def __new__(cls, *args, **kwargs):
         if cls._singleton is None:
-            cls._singleton = super().__new__(cls)
-            cls._singleton._queries = defaultdict(dict)
+            cls.reset()
         return cls._singleton
 
     @classmethod
@@ -66,6 +68,11 @@ class LazySQLRegistry:
     def get(cls, class_name: str, method_name: str) -> Optional[str]:
         return cls()._queries.get(class_name, {}).get(method_name, None)
 
+    @classmethod
+    def reset(cls):
+        cls._singleton = super().__new__(cls)
+        cls._singleton._queries = defaultdict(dict)
+
 
 class LazyHydratorRegistry:
     _singleton = None
@@ -73,8 +80,7 @@ class LazyHydratorRegistry:
 
     def __new__(cls, *args, **kwargs):
         if cls._singleton is None:
-            cls._singleton = super().__new__(cls)
-            cls._singleton._hydrators = defaultdict(dict)
+            cls.reset()
         return cls._singleton
 
     @classmethod
@@ -87,3 +93,8 @@ class LazyHydratorRegistry:
     @classmethod
     def get(cls, class_name: str, method_name: str) -> Optional[Hydrator]:
         return cls()._hydrators.get(class_name, {}).get(method_name, None)
+
+    @classmethod
+    def reset(cls):
+        cls._singleton = super().__new__(cls)
+        cls._singleton._hydrators = defaultdict(dict)
